from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(
    name: Annotated[
        str, doctyper.Argument(envvar=["AWESOME_NAME", "GOD_NAME"])
    ] = "World",
):
    print(f"Hello Mr. {name}")


if __name__ == "__main__":
    app()



import time

import doctyper
from rich.progress import Progress, SpinnerColumn, TextColumn

app = doctyper.Typer()


@app.command()
def main():
    with Progress(
        SpinnerColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:
        progress.add_task(description="Processing...", total=None)
        progress.add_task(description="Preparing...", total=None)
        time.sleep(5)
    print("Done!")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(user_name: Annotated[str, doctyper.Option("-n")]):
    print(f"Hello {user_name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main(name: str, email: str = doctyper.Option(..., prompt=True)):
    print(f"Hello {name}, your email is: {email}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main(force: bool = doctyper.Option(False, "--force/--no-force", "-f/-F")):
    if force:
        print("Forcing operation")
    else:
        print("Not forcing")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main():
    delete = doctyper.confirm("Are you sure you want to delete it?")
    if not delete:
        print("Not deleting")
        raise doctyper.Abort()
    print("Deleting it!")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(
    name: Annotated[str, doctyper.Option(help="The name to say hi to.")] = "World",
):
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main(name: str = doctyper.Option("World", help="The name to say hi to.")):
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main(fullname: str = doctyper.Option("Wade Wilson", show_default=False)):
    print(f"Hello {fullname}")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(
    id: Annotated[int, doctyper.Argument(min=0, max=1000)],
    rank: Annotated[int, doctyper.Option(max=10, clamp=True)] = 0,
    score: Annotated[float, doctyper.Option(min=0, max=100, clamp=True)] = 0,
):
    print(f"ID is {id}")
    print(f"--rank is {rank}")
    print(f"--score is {score}")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(name: Annotated[str, doctyper.Argument()] = "Wade Wilson"):
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def create(username: str):
    print(f"Creating user: {username}")


@app.command()
def delete(username: str):
    print(f"Deleting user: {username}")


@app.callback(invoke_without_command=True)
def main():
    """
    Manage users in the awesome CLI app.
    """
    print("Initializing database")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(config: Annotated[doctyper.FileText, doctyper.Option(mode="a")]):
    config.write("This is a single line\n")
    print("Config line written")


if __name__ == "__main__":
    app()



import importlib
import subprocess
import sys
from pathlib import Path
from types import ModuleType

import pytest
from doctyper.testing import CliRunner

from ....utils import needs_py310

runner = CliRunner()


@pytest.fixture(
    name="mod",
    params=[
        pytest.param("tutorial001_py39"),
        pytest.param("tutorial001_py310", marks=needs_py310),
        pytest.param("tutorial001_an_py39"),
        pytest.param("tutorial001_an_py310", marks=needs_py310),
    ],
)
def get_mod(request: pytest.FixtureRequest) -> ModuleType:
    module_name = f"docs_src.parameter_types.path.{request.param}"
    mod = importlib.import_module(module_name)
    return mod


def test_no_path(tmpdir, mod: ModuleType):
    Path(tmpdir) / "config.txt"
    result = runner.invoke(mod.app)
    assert result.exit_code == 1
    assert "No config file" in result.output
    assert "Aborted" in result.output


def test_not_exists(tmpdir, mod: ModuleType):
    config_file = Path(tmpdir) / "config.txt"
    if config_file.exists():  # pragma: no cover
        config_file.unlink()
    result = runner.invoke(mod.app, ["--config", f"{config_file}"])
    assert result.exit_code == 0
    assert "The config doesn't exist" in result.output


def test_exists(tmpdir, mod: ModuleType):
    config_file = Path(tmpdir) / "config.txt"
    config_file.write_text("some settings")
    result = runner.invoke(mod.app, ["--config", f"{config_file}"])
    config_file.unlink()
    assert result.exit_code == 0
    assert "Config file contents: some settings" in result.output


def test_dir(mod: ModuleType):
    result = runner.invoke(mod.app, ["--config", "./"])
    assert result.exit_code == 0
    assert "Config is a directory, will use all its config files" in result.output


def test_script(mod: ModuleType):
    result = subprocess.run(
        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
        capture_output=True,
        encoding="utf-8",
    )
    assert "Usage" in result.stdout



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(
    name: Annotated[str, doctyper.Argument(help="Who to greet")],
    lastname: Annotated[
        str,
        doctyper.Argument(help="The last name", rich_help_panel="Secondary Arguments"),
    ] = "",
    age: Annotated[
        str,
        doctyper.Argument(help="The user's age", rich_help_panel="Secondary Arguments"),
    ] = "",
):
    """
    Say hi to NAME very gently, like Dirk.
    """
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(verbose: Annotated[int, doctyper.Option("--verbose", "-v", count=True)] = 0):
    print(f"Verbose level is {verbose}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main(
    project_name: str = doctyper.Option(..., prompt=True, confirmation_prompt=True),
):
    print(f"Deleting project {project_name}")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(force: Annotated[bool, doctyper.Option("--force")] = False):
    if force:
        print("Forcing operation")
    else:
        print("Not forcing")


if __name__ == "__main__":
    app()



import random
from typing import Annotated

import doctyper

app = doctyper.Typer()


def get_name():
    return random.choice(["Deadpool", "Rick", "Morty", "Hiro"])


@app.command()
def main(name: Annotated[str, doctyper.Argument(default_factory=get_name)]):
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



import subprocess
import sys

from doctyper.testing import CliRunner

from docs_src.commands.help import tutorial003_py39 as mod

app = mod.app

runner = CliRunner()


def test_help():
    result = runner.invoke(app, ["--help"])
    assert result.exit_code == 0
    assert "create" in result.output
    assert "Create a user." in result.output
    assert "delete" in result.output
    assert "(deprecated)" in result.output
    assert "Delete a user." in result.output


def test_help_delete():
    result = runner.invoke(app, ["delete", "--help"])
    assert result.exit_code == 0
    assert "(deprecated)" in result.output
    assert "Delete a user." in result.output


def test_call():
    # Mainly for coverage
    result = runner.invoke(app, ["create", "Camila"])
    assert result.exit_code == 0
    result = runner.invoke(app, ["delete", "Camila"])
    assert result.exit_code == 0


def test_script():
    result = subprocess.run(
        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
        capture_output=True,
        encoding="utf-8",
    )
    assert "Usage" in result.stdout



import doctyper

app = doctyper.Typer()


@app.command()
def main(name: str = doctyper.Argument("World", envvar="AWESOME_NAME")):
    print(f"Hello Mr. {name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


@app.command()
def main(good: bool = True):
    message_start = "everything is "
    if good:
        ending = doctyper.style("good", fg=doctyper.colors.GREEN, bold=True)
    else:
        ending = doctyper.style("bad", fg=doctyper.colors.WHITE, bg=doctyper.colors.RED)
    message = message_start + ending
    doctyper.echo(message)


if __name__ == "__main__":
    app()



from typing import Annotated, Optional

import doctyper

app = doctyper.Typer()


def name_callback(value: str):
    print("Validating name")
    if value != "Camila":
        raise doctyper.BadParameter("Only Camila is allowed")
    return value


@app.command()
def main(
    name: Annotated[Optional[str], doctyper.Option(callback=name_callback)] = None,
):
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



from typing import Annotated

import doctyper

app = doctyper.Typer()


@app.command()
def main(
    project_name: Annotated[
        str, doctyper.Option(prompt=True, confirmation_prompt=True)
    ],
):
    print(f"Deleting project {project_name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()


def name_callback(value: str):
    print("Validating name")
    if value != "Camila":
        raise doctyper.BadParameter("Only Camila is allowed")
    return value


@app.command()
def main(name: str | None = doctyper.Option(default=None, callback=name_callback)):
    print(f"Hello {name}")


if __name__ == "__main__":
    app()



import doctyper

app = doctyper.Typer()

users_app = doctyper.Typer()
app.add_typer(users_app, name="users", help="Manage users in the app.")


@users_app.command()
def create(name: str):
    print(f"Creating user: {name}")


if __name__ == "__main__":
    app()
